From 5df71b2d5f34f3fd9b56672012d7435a24546ad3 Mon Sep 17 00:00:00 2001
From: Alexandru Bercuci <abercuci@niham.nipne.ro>
Date: Wed, 19 Jun 2024 21:19:16 +0300
Subject: [PATCH] modify doc style

---
 core/detectors/trd/CbmTrdParSetAsic.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/core/detectors/trd/CbmTrdParSetAsic.h b/core/detectors/trd/CbmTrdParSetAsic.h
index 97bce9aed2..6816e0febc 100644
--- a/core/detectors/trd/CbmTrdParSetAsic.h
+++ b/core/detectors/trd/CbmTrdParSetAsic.h
@@ -39,11 +39,11 @@ public:
 
   /** \brief Search for the module in the setup parameters by equipement id 
    * \param[in] eqid equipment id from HW
    * \param[out] crob_id index of the ROB (crob in legacy mode) on the module
    * \param[out] lnk_id index of optical link on the ROB (not used in legacy mode); 0 for down, 1 for up  
    * \return module id in the setup
    */
-  virtual int FindModuleByEqId(uint16_t eqid, uint8_t& crob_id, uint8_t& lnk_id) const;
+  virtual int FindModuleByEqId(uint16_t eqid, uint8_t& rob_id, uint8_t& lnk_id) const;
   /** \brief Build the ASICs par for the current module from the info stored in the param file 
    * It applies to the list of ASICs.
    * \param module ASICs par (FASP or SPADIC)
@@ -39,11 +39,11 @@ public:
   /** \brief Search for the module in the setup parameters by equipement id 
    * \param[in] eqid equipment id from HW
-   * \param[out] crob_id index of the ROB (crob in legacy mode) on the module
+   * \param[out] rob_id index of the ROB (CROB in legacy mode) on the module
    * \param[out] lnk_id index of optical link on the ROB (not used in legacy mode); 0 for down, 1 for up  
    * \return module id in the setup
-- 
GitLab